@@ -6,8 +6,6 @@ import operator
 import select
 import sys
 
-from . import scheduler
-
 
 class Poll(object):
     "a greenhouse poller using the poll system call"
@@ -65,7 +63,9 @@ class Poll(object):
             self._registry.pop(fd)
 
     def poll(self, timeout):
-        return self._poller.poll(timeout * 1000)
+        if timeout is not None:
+            timeout *= 1000
+        return self._poller.poll(timeout)
 
     def _update_registration(self, fd, from_mask, to_mask):
         if from_mask != to_mask:
@@ -88,6 +88,8 @@ class Epoll(Poll):
     _POLLER = getattr(select, "epoll", None)
 
     def poll(self, timeout):
+        if timeout is None:
+            timeout = -1
         return self._poller.poll(timeout)
 
 
@@ -213,7 +215,3 @@ def best():
         return Poll()
 
     return Select()
-
-
-def set(poller=None):
-    scheduler.state.poller = poller or best()
